Learn R Programming

statsguRu (version 0.1.1)

dispBatsmanDismissalsByBowlerType: Plots a pie chart of Dismissal Summary vs type and style of Bowlers

Description

This function takes in output of splitDismissalSummary and Plots a pie chart of Dismissal Summary vs type and style of Bowlers.

Usage

dispBatsmanDismissalsByBowlerType(data)

Arguments

data

Output of splitDismissalSummary().

Value

Plots a pie chart of Dismissal Summary vs type and style of Bowlers

Examples

Run this code
# NOT RUN {
sachin = getDismissalSummary(35320,11)
sachin1 = splitDismissalSummary(sachin)
dispBatsmanDismissalsByBowlerType(sachin1)
# }

Run the code above in your browser using DataLab