Learn R Programming

statsguRu (version 0.1.1)

dispBowlerDismissals: Plots a pie chart of Dismissal Type Summary of a Bowler.

Description

This function takes in output of splitDismissalSummary and plots the Dismissal Type Summary of a Bowler as a pie chart.

Usage

dispBowlerDismissals(data)

Arguments

data

Output of splitWicketsSummary().

Value

Plots a pie chart of Dismissal Type Summary of a Bowler.

Examples

Run this code
# NOT RUN {
sachin = getWicketsSummary(35320,1)
sachin1 = splitWicketsSummary(sachin,1)
dispBowlerDismissals(sachin1)
# }

Run the code above in your browser using DataLab