Learn R Programming

statsguRu (version 0.1.1)

dispWktsTakenAtHostCountry: Displays Barplot of Players's Wickets by List of Host Countries

Description

This function takes in "Bowling Summary" dataframe modified after splitBowlingSummary and plots a player's sum of wickets taken against every opposition team.

Usage

dispWktsTakenAtHostCountry(data)

Arguments

data

Output of splitBowlingSummary.

Value

Plots a player's sum of wickets taken in every host country

Examples

Run this code
# NOT RUN {
sachin = getBowlingSummary(35320,2)
sachin1 = splitBowlingSummary(sachin,2)
dispWktsTakenAtHostCountry(sachin1)
# }

Run the code above in your browser using DataLab