powered by
This function takes in output of splitDismissalSummary and Plots a pie chart of Dismissal Summary vs type and style of Bowlers.
dispBatsmanDismissalsByBowlerType(data)
Output of splitDismissalSummary().
Plots a pie chart of Dismissal Summary vs type and style of Bowlers
# NOT RUN { sachin = getDismissalSummary(35320,11) sachin1 = splitDismissalSummary(sachin) dispBatsmanDismissalsByBowlerType(sachin1) # }
Run the code above in your browser using DataLab