powered by
This function takes in output of splitDismissalSummary and plots the Dismissal Type Summary of a Bowler as a pie chart.
dispBowlerDismissals(data)
Output of splitWicketsSummary().
Plots a pie chart of Dismissal Type Summary of a Bowler.
# NOT RUN { sachin = getWicketsSummary(35320,1) sachin1 = splitWicketsSummary(sachin,1) dispBowlerDismissals(sachin1) # }
Run the code above in your browser using DataLab