dispWktsTakenAtHostCountry: Displays Barplot of Players's Wickets by List of Host Countries
Description
This function takes in "Bowling Summary" dataframe modified after splitBowlingSummary and plots a player's sum of wickets taken against every opposition team.
Usage
dispWktsTakenAtHostCountry(data)
Arguments
data
Output of splitBowlingSummary.
Value
Plots a player's sum of wickets taken in every host country